pub trait BoxedCatalogBuilder: Send {
// Required methods
fn with_storage_factory(
self: Box<Self>,
storage_factory: Arc<dyn StorageFactory>,
) -> Box<dyn BoxedCatalogBuilder>;
fn with_kms_client_factory(
self: Box<Self>,
kms_client_factory: Arc<dyn KmsClientFactory>,
) -> Box<dyn BoxedCatalogBuilder>;
fn with_runtime(
self: Box<Self>,
runtime: Runtime,
) -> Box<dyn BoxedCatalogBuilder>;
fn load<'async_trait>(
self: Box<Self>,
name: String,
props: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn Catalog>>> + Send + 'async_trait>>
where Self: 'async_trait;
}Required Methods
Sourcefn with_storage_factory(
self: Box<Self>,
storage_factory: Arc<dyn StorageFactory>,
) -> Box<dyn BoxedCatalogBuilder>
fn with_storage_factory( self: Box<Self>, storage_factory: Arc<dyn StorageFactory>, ) -> Box<dyn BoxedCatalogBuilder>
Sets the storage factory used to build the catalog’s FileIO; see
CatalogBuilder::with_storage_factory.
Sourcefn with_kms_client_factory(
self: Box<Self>,
kms_client_factory: Arc<dyn KmsClientFactory>,
) -> Box<dyn BoxedCatalogBuilder>
fn with_kms_client_factory( self: Box<Self>, kms_client_factory: Arc<dyn KmsClientFactory>, ) -> Box<dyn BoxedCatalogBuilder>
Sets the KMS client factory used to enable table encryption; see
CatalogBuilder::with_kms_client_factory.
Sourcefn with_runtime(
self: Box<Self>,
runtime: Runtime,
) -> Box<dyn BoxedCatalogBuilder>
fn with_runtime( self: Box<Self>, runtime: Runtime, ) -> Box<dyn BoxedCatalogBuilder>
Sets the runtime the catalog, and the tables it creates, spawn their
tasks on; see CatalogBuilder::with_runtime.